/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EZBApplicationJNDIResolver.java 2981 2008-04-27 15:58:00Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.console.registry.service;

import java.util.ArrayList;
import java.util.List;

/**
 * Represents a registry protocol
 */
public class RegistryProtocol {

    /**
     * Name of the protocol.
     */
    private String name = null;

    /**
     * Provider URL.
     */
    private String providerURL = null;

    /**
     * List of JNDI names.
     */
    private List<String> jndiNames = null;

    /**
     * List of JNDI values
     */
    private List<String> jndiValues = null;

    /**
     * List of JNDI types
     */
    private List<String> jndiTypes = null;

    /**
     * Default constructor
     */
    public RegistryProtocol() {
        this.jndiNames = new ArrayList<String>();
        this.jndiValues = new ArrayList<String>();
        this.jndiTypes = new ArrayList<String>();
    }

    /**
     * @return the name of the protocol
     */
    public String getName() {
        return name;
    }

    /**
     * @param name The name of the protocol to set
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return the provider URL
     */
    public String getProviderURL() {
        return providerURL;
    }

    /**
     * @param providerURL The provider URL to set
     */
    public void setProviderURL(final String providerURL) {
        this.providerURL = providerURL;
    }

    /**
     * @return the list of JNDI names
     */
    public List<String> getJndiNames() {
        return jndiNames;
    }

    /**
     * @param jndiNames The list of JNDI name to set
     */
    public void setJndiNames(final List<String> jndiNames) {
        this.jndiNames = jndiNames;
    }

    /**
     * @return the list of JNDI values
     */
    public List<String> getJndiValues() {
        return this.jndiValues;
    }

    /**
     * @param jndiValues The list of JNDI values to set
     */
    public void setJndiValues(final List<String> jndiValues) {
        this.jndiValues = jndiValues;
    }

    /**
     * @return the list of JNDI value types
     */
    public List<String> getJndiTypes() {
        return this.jndiTypes;
    }

    /**
     * @param jndiTypes The list of JNDI value type to set
     */
    public void setJnditypes(final List<String> jndiTypes) {
        System.out.println("SET_TYPES");
        this.jndiTypes = jndiTypes;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder(RegistryProtocol.class.getSimpleName());
        sb.append("[name=");
        sb.append(name);
        sb.append(", providerURL=");
        sb.append(providerURL);
        sb.append(", JNDI Names=");
        sb.append(jndiNames);
        sb.append(", JNDI Values=");
        sb.append(jndiValues);
        sb.append(", JNDI types=");
        sb.append(jndiTypes);
        sb.append("]");
        return sb.toString();
    }
}
